/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */
package org.gnu.glade;

import java.lang.reflect.Method;

import org.gnu.gtk.event.ExpanderEvent;
import org.gnu.gtk.event.ExpanderListener;

/**
 * ToolBarListener delegate class.
 */
public class ExpanderDelegate extends ListenerDelegate implements
        ExpanderListener {

    public ExpanderDelegate(String signal, Object owner, Method handler,
            Object target) throws NoSuchMethodException {
        super(signal, owner, handler, target);
    }

    public boolean expanderEvent(ExpanderEvent event) {
        return fireEvent(event);
    }
}
